#ifndef LICQ_H
#define LICQ_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <qapp.h>

#include "icq.h"
#include "licqgui.h"

#ifdef USE_KDE
#include "klicq.h"
class Licq : public KApplication
#else
class Licq : public QApplication
#endif
{
public:
   Licq(int argc, char **argv);
   ~Licq(void);
   bool quitNow(void);
protected:
   void usage(void);
   bool installBaseDir(void);
   bool quitNowVal;
   ICQ *icq;
   CMainWindow *licqgui;
#ifdef USE_KDE
   KLicq *klicq;
#endif

};

#endif
